/*
       winpopup.h
       GNU Licence

       author: Rafal Michniewicz 
        email: <rafim@data.pl>
       jabber: rafim@jabber.airm.net
    home page: http://smbc.airm.net
*/

void RsendWinpopup(char *RpathToSmbclient, char *Rrcp, char *Rtxt);

